.. _apidoc:

API Documentation
=================

The user only interacts with the :py:mod:`yeadon.human` module. The interface
to the other modules is only useful to developers.

:mod:`yeadon` Package
---------------------

.. automodule:: yeadon.__init__
    :members:
    :undoc-members:
    :show-inheritance:

.. toctree::
   :maxdepth: 2

   human.rst
   segment.rst
   solid.rst
